@@ -3,6 +3,7 @@ from datetime import datetime
 from typing import Any, Dict, Optional
 
 import arrow
+from scalpl import Cut
 
 
 @dataclass
@@ -27,6 +28,9 @@ class BaseData:
     * payload (dict):               Original payload received from prospection.
     * timeit                        Time in seconds for retrieving data.
     * datasource_base_url           Data Source Base Url
+    * current_environment           Current AWS Environment. Available environments are:
+                                    local, dev, staging, production. Default: production
+    * settings                      Snatch Settings.
     """
 
     tax_id: Optional[str] = None
@@ -36,6 +40,11 @@ class BaseData:
     payload: Optional[Dict[str, Any]] = None
     timeit: Optional[float] = None
     datasource_base_url: Optional[str] = None
+    settings: Optional[Cut] = None
+
+    @property
+    def current_environment(self) -> str:
+        return self.settings["current_environment"]
 
     def find_current_status(self, max_days_old: int):
         """Find current Status for Data.
