@@ -31,7 +31,7 @@ class SecretManager:
         if self._client:
             return self._client
 
-        region_name = self.current_env_data["project"]["aws_region"]
+        region_name = os.getenv("AWS_REGION", "us-east-1")
         if not os.getenv("AWS_ACCESS_KEY_ID_SHARED", None):
             # just initialize, will check for `.aws/credentials` file
             self._client = boto3.client("secretsmanager", region_name=region_name)
